//-----------------------------------------------------------------------------
//    Example for STM32Butterfly + KAmodMEMS2 + KAmodTFT2
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//                     http://www kamami.com
//-----------------------------------------------------------------------------
//
//
// This program reads KAmodMEMS2 orientation (x, y and z angles). Then it draws
// cube rotated with this angles on KAmodTFT2.
//
// Connections and board setup:
//
// STM32Butterfly
//		BOOT0 and BOOT1 jumpers in 0 position
//
// KAmodTFT2 
//		PWR jumper (JP1) in 3V position
//
//
// 	KAmodTFT2	<->		STM32Butterfly
//	GND					GND (PC)
//	CLK					PC5 (PC)
//	DIN					PC4 (PC)
//	RES					PC7 (PC)
//	V+					+ (PC)
//	SCE					PC6 (PC)
//
//	KAmodMEMS2	<->		STM32Butterfly
//	Use CAB_HU06-30 from www.kamami.com to connect Con2 of KAmodMEMS2 and 
//	STM32Butterfly SPI connector except for first pin, that must be connected
//	to + pin of PD or PE connector.
//-----------------------------------------------------------------------------
	

#include "stm32f10x_lib.h"
#include "board.h"
#include "lis35.h"
#include "lcdlib.h"

int main(void)
{
	signed char x, y, z, xo = 0, yo = 0, zo = 0;		// x, y, z - MEMS orientation,
														// xo, yo, zo - previous MEMS orientation
														// 				used to check whether MEMS 
														//				position changed
	signed char contrast = 42;							// contrast value
	unsigned int k, l;

	RCC_Configuration();
	NVIC_Configuration();
	GPIO_Configuration();
	 
	// Initialize LCD
	InitLcdNokia();

	// Set contrast
	SetContrast(contrast);

	
	
	// *****************************************************************
	// Uncomment this code to find best contrast value. Contrast is
	// adjusted with joystick (up-down).
	// *****************************************************************
	 					 
	// Draw three rectangles (red, green and blue)
	/*
	for (k=0; k<44; k++)
		for (l=0; l<132; l++)
			LCDSetPixel(k,l, 0xF);
	for (k=44; k<88; k++)
		for (l=0; l<132; l++)
			LCDSetPixel(k,l, 0xF0);
	for (k=88; k<132; k++)
		for (l=0; l<132; l++)
			LCDSetPixel(k,l, 0xF00);				
  
	// Adjust contrast with joystick

	while(1)
	{					  
		if (JOY_PORT->IDR & JOY_UP)
			SetContrast(contrast == 63 ? contrast : ++contrast);
		if (JOY_PORT->IDR & JOY_DOWN)
			SetContrast(contrast == -64 ? contrast : --contrast);
		for (k = 0; k < 0xFFFFF; k++); 

	}
	// ******************************************************************
	// */


	// Clear screen
	LCDClearScreen(0x0);

	// Configure SPI and initialize MEMS
	SPI_Configuration();
	if (InitializeLIS35() == LIS35_ERROR)
	{
		LCDClearScreen(0xF);
		while(1);
	}
	
	
	while(1)
	{
		// Read KAmodMEMS orientation
		LIS35_GetPosition(&x, &y, &z);


		// If MEMS moved then redraw cube
		if (abs(xo - x) > 3 || abs(yo - y) > 3 || abs(zo - z) > 3)
		{
			// Erase previous cube
			DrawCube(xo, yo, zo, 0x0);

			// Draw new cube
			DrawCube(x, y, z, 0xFFF);

			// Store old orientation
			xo = x; yo = y; zo = z;
		}
	}
}

